@@ -258,7 +258,7 @@ plotPrototypes <- function(sommap, type, variable, my.palette, show.names,
       dataplot <- data.frame(cbind("x" = sommap$parameters$the.grid$coord[ ,1],
                                    "y" = sommap$parameters$the.grid$coord[ ,2],
                                    "z" = values))
-      ggplot(data = dataplot, aes_string(x = "x", y = "y", z = "z")) + 
+      ggplot(data = dataplot, aes(x = .data$x, y = .data$y, z = .data$z)) + 
         metR::geom_contour_fill(na.fill = TRUE) + 
         labs(title = "Distances between prototypes") + 
         scale_fill_distiller(palette = "PRGn")
@@ -281,8 +281,8 @@ plotPrototypes <- function(sommap, type, variable, my.palette, show.names,
     if (is.null(args$sc)) {  #### Super cluster case
       dataplot <- data.frame(x = proj.coord[ ,1], y = proj.coord[ ,2], 
                              "labels" = args$labels)
-      ggplot(dataplot, aes_string(x = "x", y = "y")) + 
-        geom_text(aes_string(label = "labels"), alpha = 0.7, size = args$cex, 
+      ggplot(dataplot, aes(x = .data$x, y = .data$y)) + 
+        geom_text(aes(label = .data$labels), alpha = 0.7, size = args$cex, 
                   fontface = "bold") +
         labs(x = "x", y = "y", title = "Prototypes visualization by MDS") +
         theme_bw()
@@ -290,8 +290,8 @@ plotPrototypes <- function(sommap, type, variable, my.palette, show.names,
       dataplot <- data.frame(x = proj.coord[,1], y = proj.coord[,2], 
                              "labels" = args$labels, 
                              "Super_Cluster" = as.factor(args$sc))
-      ggplot(dataplot, aes_string(x = "x", y = "y")) + 
-        geom_text(aes_string(label = "labels", col = "Super_Cluster"), 
+      ggplot(dataplot, aes(x = "x", y = "y")) + 
+        geom_text(aes(label = .data$labels, col = .data$Super_Cluster), 
                   alpha = 0.7, size = args$cex, fontface = "bold") +
         labs(x = "x", y = "y", title = "Prototypes visualization by MDS") +
         theme_bw()
@@ -300,7 +300,7 @@ plotPrototypes <- function(sommap, type, variable, my.palette, show.names,
   } else if (type == "grid.dist") {
     if (sommap$parameters$type == "relational") {
       the.distances <- protoDist(sommap, "complete")
-     if (sum(the.distances<0) > 0) {
+     if (any(the.distances < 0)) {
       stop("Impossible to plot 'grid.dist'!", call. = TRUE)
      } else {
        the.distances <- sqrt(the.distances)
@@ -309,7 +309,7 @@ plotPrototypes <- function(sommap, type, variable, my.palette, show.names,
     } else the.distances <- dist(sommap$prototypes)
     dataplot <- data.frame("x" = as.vector(the.distances), 
                            "y" = as.vector(dist(sommap$parameters$the.grid$coord)))
-    ggplot(dataplot, aes_string(x = "x", y = "y")) + 
+    ggplot(dataplot, aes(x = .data$x, y = .data$y)) + 
       geom_point(shape = 19, alpha = 0.7, size = 1) +
       labs(x = "prototype distances", y = "grid distances", 
            title = "Distances between protoypes (input space vs. grid)") +
@@ -591,6 +591,8 @@ plotAdd <- function(sommap, type, variable, proportional, my.palette,
 #' @seealso \code{\link{trainSOM}} to run the SOM algorithm, that returns a 
 #' \code{somRes} class object.
 #' 
+#' @importFrom rlang .data
+#' 
 #' @examples
 #' # run the SOM algorithm on the numerical data of 'iris' data set
 #' iris.som <- trainSOM(x.data = iris[, 1:4], nb.save = 2)
